# Resources 

resource "openstack_networking_secgroup_v2" "secgroup_db" {
  name        = "${var.system_name}-secgrp_db"
}

# Basic Rule that allows MySQL to talk within the cluster
resource "openstack_networking_secgroup_rule_v2" "secgroup_rule_db_mysql_from_local" {
  direction         = "ingress"
  ethertype         = "IPv4"
  protocol          = "tcp"
  port_range_min    = 3306
  port_range_max    = 3306
  remote_group_id   = openstack_networking_secgroup_v2.secgroup_db.id
  security_group_id = openstack_networking_secgroup_v2.secgroup_db.id
}

# Basic Rule that allows Galera replication within the cluster
resource "openstack_networking_secgroup_rule_v2" "secgroup_rule_db_galera_from_local" {
  direction         = "ingress"
  ethertype         = "IPv4"
  protocol          = "tcp"
  port_range_min    = 4567
  port_range_max    = 4568
  remote_group_id   = openstack_networking_secgroup_v2.secgroup_db.id
  security_group_id = openstack_networking_secgroup_v2.secgroup_db.id
}

# Basic Rule that allows Galera replication within the cluster
resource "openstack_networking_secgroup_rule_v2" "secgroup_rule_db_galera_from_local_udp" {
  direction         = "ingress"
  ethertype         = "IPv4"
  protocol          = "udp"
  port_range_min    = 4567
  port_range_max    = 4568
  remote_group_id   = openstack_networking_secgroup_v2.secgroup_db.id
  security_group_id = openstack_networking_secgroup_v2.secgroup_db.id
}

# Basic Rule that allows State Snapshot Transfer SST to talk within the cluster
resource "openstack_networking_secgroup_rule_v2" "secgroup_rule_db_sst_from_local" {
  direction         = "ingress"
  ethertype         = "IPv4"
  protocol          = "tcp"
  port_range_min    = 4444
  port_range_max    = 4444
  remote_group_id   = openstack_networking_secgroup_v2.secgroup_db.id
  security_group_id = openstack_networking_secgroup_v2.secgroup_db.id
}

# Basic Rule that allows Percona Monitoring and Management PMM to talk within the cluster
resource "openstack_networking_secgroup_rule_v2" "secgroup_rule_db_pmm_from_local" {
  direction         = "ingress"
  ethertype         = "IPv4"
  protocol          = "tcp"
  port_range_min    = 9200
  port_range_max    = 9200
  remote_group_id   = openstack_networking_secgroup_v2.secgroup_db.id
  security_group_id = openstack_networking_secgroup_v2.secgroup_db.id
}

# Basic Rule that allows keepalived
resource "openstack_networking_secgroup_rule_v2" "secgroup_rule_db_keepalived_from_all" {
  direction         = "ingress"
  ethertype         = "IPv4"
  protocol          = "tcp"
  port_range_min    = 112
  port_range_max    = 112
  remote_ip_prefix  = "0.0.0.0/0"
  security_group_id = openstack_networking_secgroup_v2.secgroup_db.id
}


# Basic Rule that allows SSH
resource "openstack_networking_secgroup_rule_v2" "secgroup_rule_db_ssh_from_all" {
  direction         = "ingress"
  ethertype         = "IPv4"
  protocol          = "tcp"
  port_range_min    = 22
  port_range_max    = 22
  remote_ip_prefix  = "0.0.0.0/0"
  security_group_id = openstack_networking_secgroup_v2.secgroup_db.id
}

# Basic Rule that allow ICMP to communicate to servers
resource "openstack_networking_secgroup_rule_v2" "secgroup_rule_db_icmp" {
  direction         = "ingress"
  ethertype         = "IPv4"
  protocol          = "icmp"
  remote_ip_prefix  = "0.0.0.0/0"
  security_group_id = openstack_networking_secgroup_v2.secgroup_db.id
}
